;--------------------------------------------
;		 F I L E S L I B
;		    library
;
;     	FARGO II / PLUSSHELL Header File
;
;	(c) NeXO Software, Benoit SCHERRER
;---------------------------------------------

;---------------------------------------------
; All function definitions
;---------------------------------------------
fileslib::move_file	equ	fileslib@0000
fileslib::copy_file	equ	fileslib@0001
fileslib::delete_file	equ	fileslib@0002
fileslib::delete_folder	equ	fileslib@0003
fileslib::create_file	equ	fileslib@0004
fileslib::create_folder	equ	fileslib@0005
fileslib::find_var	equ	fileslib@0006
fileslib::rename_item	equ	fileslib@0007

fileslib::add_var_entry	equ	fileslib@0008
fileslib::find_var_pos	equ	fileslib@0009
fileslib::insert_var_entry	equ	fileslib@000A
fileslib::delete_var_entry	equ	fileslib@000B

fileslib::is_file_in_use	equ	fileslib@000C

;********************************************
;    E R R O R      C O D E S
;
;
; * Not enough memory :
MEMORY_ERROR	equ	670
;
;
; * The file/folder name already exist :
ALREADY_NAME	equ	270
;
;
; * The item index is out of the list :
ITEM_OUT	equ	350
;
;
; * Cannot delete/move a file since it is a
;	already used Fargo program
FILE_IN_USE	equ	970
;
;
; * Not an empty folder. (use by delete_folder
;	if d1 is not null.
FOLD_NOTEMPTY	equ	150
;
;
; * Cannot use Move/Delete with archived variables
;	(TI92+ version)
ARCH_VAR	equ	980
;
;----------------------------------------------

;////////////////////////////////////////////////
;///////////// FileLib Functions ////////////////
;////////////////////////////////////////////////

;--------------------------------------
; move_file
;
; > Move the file number d2 from the folder
; d0 to the folder d1
; (Check if the file is a fargo program in use)
;
;input>	d0.w : hdl of source folder
;	d1.w : hdl of dest folder
;	d2.w : zero based index of the file
;
;out>	d1.w : Error code 
;
; DESTROY ONLY d1
;---------------------------------------

;--------------------------------------
; copy_file
;
; > Copy the file number d2 from the folder
; d0 to the folder d1
; (If the source file is a fargo program with a
; no-zero relocated number because it is in use
; this function will clear the relocated number
; of the dest file.)
;
;
;input>	d0.w : hdl of source folder
;	d1.w : hdl of dest folder
;	d2.w : zero based index of the file
;
;out>	d1.w : Error code
;
; DESTROY ONLY d1
;---------------------------------------

;---------------------------------------
; delete_file
;
;> Delete the file d2 of the d0 hdl folder
; Check if the file is a fargo program in use
;
;input>	d0.w : Handle of folder where the file is
; 	d2.w : zero based index of the file to delete
;
;out>	d1.w : Error Code
;
; DESTROY ONLY d1
;---------------------------------------

;---------------------------------------
; delete_folder
;
;> Delete the folder d2, and all the files into
; if it is required
; (Check if files are fargo program in use)
;
;input>	d1.w : 	0 if folders files must be deleted 
;		 before
;		else don't delete files and return
;		 an error if there are files
;	d2.w : zero based index of the folder
;
;out>	d1.w : Error code
;
; DESTROY ONLY d1
;----------------------------------------

;----------------------------------------
; create_file
;
;> Create a file in the folder  d1.
;
;input>	d1.w : folder hdl
;	d2.l : file size (size of data)
;	d3.b : file type (cf txt file)
;	d4.w : flags
;	a4.l : file name
;
;out>	a0.l : address of the file
;	d0.w : Handle of the file
;	d1.w : Error Code
;
; DESTROY ONLY a0,d0,d1
;----------------------------------------

;-----------------------------------------
; create_folder
;
;> Create a folder
;
;input> a4.l : folder name
;	d4.w : flags
;
;out>	d0.w : hdl of folder if succeed
;	d1.w : Error Code
;	a0.l : Point folder buffer
;
; DESTROY ONLY a0,d1
;-----------------------------------------


;--------------------------------------------------
; find_var
;
;> Find a var in the VAT. (so a folder or a file)
;
;input>	a0.l : Name of file to search
;	d0.w : hdl of file list
;
;out>	d0.w : if succeed, index of the finded item
;	d1.w : 0 if error
;		or else handle of finded item
;	a0.l : if succeed, address of the item
;	a1.l : addr of found item VAT entry
;
; DESTROY ONLY d0,d1,a0,a1
;--------------------------------------------------

;---------------------------------------
; rename_item
;
;> Rename an item (a file or a folder) in a VAT list
;
;input>	d0.w : hdl of the VAT list
;	a4.l : new file name
;	d2.w : zero based index of item to rename in the 
;		VAT list
;out>	d1.w : Error Code
;	a0.l : Addr of new item VAT entry
; DESTROY ONLY d1 and a0
;---------------------------------------

;-----------------------------------------------------
; add_var_entry
;
;>Add a var entry in the list d1. This function resize
; the list if it is needed, and put the item in the 
; right position.
;
;input>	d1.w : handle of the VAT list
;	d6.w : handle of the item you want to add
;	d4.w : flags
;	a4.l : address of folder name
;
;out>	d1.w : Error Code
;
; DESTROY ONLY d1
;------------------------------------------------------

;-----------------------------------------------------
;find_var_pos
;
;> Return the position where should be put the item
; a4 in the list a0
;
;input>	a4.l : address of file/folder name to put
;	a0.l : address of file/folder list
;
;out>	d0.w : zero based position in the list
;	d1.w : Error Code
;
; DESTROY ONLY d0,d1
;-----------------------------------------------------

;------------------------------------------------------
;insert_var_entry
;
;> Move all a block for puting a item in the pos d0
;
;input>	d0.w : zero based pos where insert the new file
;	a0.l : Pointer to nb in the VAT list
;out>	a0.l : address of created entry name
;	a1.l : address of next entry name
;
; DESTROY ONLY a0,a1
;------------------------------------------------------

;--------------------------------------------------
;delete_var_entry
;
;> Delete a var entry (move all a block)
;
;input>	d2.w : zero based index of the var
;	a0.l : Point to nb file in the VAT list
;out>	d1.w : Error Code
;
; DESTROY ONLY d1
;--------------------------------------------------

;-----------------------------------------------------
; is_file_in_use
;
;> Check if a file is a already used Fargo program
;
;input>	d2.w : zero based index of the file
;	d0.w : hdl of VAT list
;out>	d1.w : error code
;	a0.l : addr of file+2 (addr of data)
;
; DESTROY ONLY d1,a0
;----------------------------------------------------
