;=====================================================================
;                       PCTOOLS 98 PLUGINS SDK
;                (c) Benoit SCHERRER, NeXO Software
;
;---------------------------------------------------------------------
; PLUGINS SDK VERSION   : 1.00
; FILE DESCRIPTION      : Picture Viewer Plugin
;=====================================================================

	include "tios.h"                ;library includes files
	include "flib.h"
	include "api92.h"

	xdef    _main                   ;normal assembly program
	xdef    _comment

	include "pctplug.h"             ;and after we include pctplug.h

ENTRYHDL	equ	10

;--------------------------------------------------------------------
; Start of PCTOOLS 98 plugin
;--------------------------------------------------------------------

	PRG_AS_PLUGIN

sp_ext  dc.b    PIC_ID                	;specific extension ?
export  dc.b    %00011000               ;export flag byte

	dc.l    NOT_USED         	;1:Initialization of PCT98
	dc.l    NOT_USED                ;2:End of PCT98
	dc.l    NOT_USED              	;3:Key pressed
	dc.l    KeyEnter                ;4:ENTER pressed
	dc.l    CursorMoved            	;5:Cursor moved
	dc.l    NOT_USED                ;6:Show Item

END_PLUGIN_TABLE:
	;(...)                          the program can continue

	rts

;---------------------------------------------------------------------
; Function called when ENTER is pressed on a File/Folder,
; before PCT98 uses it 
;
; USE SPECIFIC EXTENSION
;
;Input>	rg2.l : Address of the current item (VAT entry)
;		selected. (from a buffer)
;Out>
;
;RETURN> REDRAW_SCREEN : request to redraw the screen
;	 SHOW_MESSAGE : request to print a message in the
;	  status bar. The message is pointed by rg2 and must
;	  be valid
;	 SKIP_PCTPROCESS : request that PCT98 don't run its
;	  KeyEnter subroutine
;---------------------------------------------------------------------
KeyEnter:
	move.l	rg2,a1			;address of selected item
	move.w	ENTRYHDL(a1),d0		;Handle of selected item
	jsr	api92::DEREFd0a0	;Get its Address
	lea	2(a0),a4		;skip file size

	jsr	flib::clr_scr		;Clear screen
	move.l	#flib::frame_rect,a5	;Addr of func for size optimization
	move.l	#$00EF000A,-(a7)	;Push y2=10 and x2=239
	move.l	#0,-(a7)		;Push y1=0 and x1=0 (size optimized)
	jsr 	(a5)
	addq.l	#8,a7			;free the stack
	
	moveq.w	#1,d0			;Set Medium Font
	jsr	api92::SetFont
	lea	title(PC),a0		;Draw title
	jsr	api92::DrawString
	
	move.w	(a4)+,d1		;Height of picture
	move.w	(a4)+,d2		;Width of picture

	move.w	d2,d0			;save d2 in
	move.w	d2,d3			;d0 and d3
	lsr.w	#3,d3			;int(width/8)
	and.w	#7,d0			;
	tst.w	d0
	bne.s	\add			
	subq.w	#1,d3
	
\add	move.l	#LCD_MEM+330,a1
	subq.w	#1,d1			;d1 = Height-1 for dbra
	cmp.w	#110,d1			;Make a vertical clipper
	bls.s	\sizok			;(I found more-than-110
	moveq.w	#110,d1			;height pictures )
\sizok	move.l	d1,-(a7)		;save height
\YLoop	move.w	d3,d0			;
\XLoop	move.b	(a4)+,(a1)+
	dbra.s	d0,\XLoop
	lea	29(a1),a1
	suba.w	d3,a1
	dbra.s	d1,\YLoop
					;Now draw size rectangles
	move.l	(a7)+,d1		;restore d1=Height
	move.l	#$00EF0079,-(a7) 	;push y2=121 and x2=239
	move.w	#10,-(a7)		;push y1
	move.w	d2,-(a7)		;push x1
	jsr 	(a5)
	addq.l	#8,a7

	add.w	#11,d1
	move.l	#$00EF0079,-(a7)	;push y2=121 and x2=239
	move.w	d1,-(a7)		;push y1
	move.w	#0,-(a7)		;push x1
	jsr 	(a5)
	addq.l	#8,a7

	jsr	flib::idle_loop		;wait for a key...

	rtplugin (SKIP_PCTPROCESS+REDRAW_SCREEN)

;---------------------------------------------------------------------
; Function called when the cursor is moved to a new item
;
; USE SPECIFIC EXTENSION
;
;Input>	rg2.l : Address of the current item (VAT entry)
;		selected. (from a buffer)
;Out>
;
;RETURN> SHOW_MESSAGE : request to print a message in the
;	  status bar. The message is pointed by rg2 and must
;	  be valid
;	 SKIP_PCTPROCESS : request that PCT98 don't print something
;	  in the status bar
;---------------------------------------------------------------------
CursorMoved:
	move.l	rg2,a1			;address of selected item
	move.w	ENTRYHDL(a1),d0		;Handle of selected file
	jsr	api92::DEREFd0a0	;Get its address
	addq.l	#2,a0			;skip file size

	lea	-601(a7),a1		;store message to show in the stack
	exg.l	a1,a0			;a0=buffer addr for api92::DecimalToStr 
					;and a1=File address
	clr.b	-(a0)			;End of string : put 0x00
	move.l	#'ture',-(a0)		;put the string 'Picture'
	move.l	#' Pic',-(a0)

	move.w	(a1)+,d0		;Get Height of picture
	jsr	api92::DecimalToStr	;convert it at (a0)

	move.b	#'x',-(a0)		;put 'x' char
	move.w	(a1),d0			;Get Width of picture
	jsr	api92::DecimalToStr	;convert it at (a0)

	move.l	a0,rg2			;Set address of message to return

	rtplugin (SHOW_MESSAGE+SKIP_PCTPROCESS)


;====================================================================
; Plugin Data
;====================================================================

title	dc.b	45,2
_comment
	dc.b    "Picture Viewer Plugin v1.0",0

	end
